import numpy as np
import pandas as pd
from glob import glob
import matplotlib
import matplotlib.pyplot as plt
import datetime
from matplotlib.font_manager import FontProperties


files = glob('predata/csv/*.csv')

df = pd.concat(
    (pd.read_csv(file, usecols=['日期', '入出境總人數_小計'], dtype={'日期': str, '入出境總人數_小計': str}, index_col='日期') for file in files))


df = df.dropna()
df['入出境總人數_小計'] = pd.to_numeric(df['入出境總人數_小計'])
df['日期'] = pd.to_datetime(df.index, format='%Y%m%d')

df['Year'] = df['日期'].dt.year
df['Month'] = df['日期'].dt.month
print(df)
df = df.filter(like='2022', axis=0)
df = df.groupby(['Year', 'Month']).sum()


chart = df.plot(kind='bar')
font = FontProperties(fname=r'Font.ttf')


for label in chart.get_xticklabels():
    label.set_fontproperties(font)  # 設定字體
# must set in top
plt.rcParams.update({'font.size': 44, "figure.figsize": (40, 30)})
plt.title('2022年出入境人口', fontproperties=font)  # 圖表標題
plt.xlabel('日期', fontproperties=font)  # x軸說明文字
plt.ylabel('人數', fontproperties=font)  # y軸說明文字
plt.legend(prop=font)  # 圖例
plt.style.use('dark_background')  # 黑色主題

plt.show()  # render
